@echo off
setlocal enabledelayedexpansion

:: ============================================================
:: EPUB Conversiescript - .md naar .epub met Pandoc
:: Laatste update: 2025-06-20
::
:: Changelog:
:: - Vervanging van verouderde 'wmic' door PowerShell Get-Date
:: - Fallback op datum van vandaag bij lege invoer
:: - Overstap van --epub-metadata XML naar --metadata vlaggen
:: - Vermeden gebruik van systeemvariabele %DATE%
:: - Invoervelden ontdaan van spaties en line breaks via PowerShell .Trim()
:: - Gebruik van !VAR! (delayed expansion) om correcte waardes te behouden
:: - PowerShell Console.Write gebruikt om onzichtbare tekens zoals '=' of '+' te voorkomen
:: - Alle metadata wordt correct opgenomen in EPUB (title, author, publisher, date)
:: - Pauzes verwijderd voor geautomatiseerd gebruik, metadata wordt alleen getoond
:: - Eindpauze toegevoegd zodat resultaat zichtbaar blijft
:: - Spaties toegevoegd bij invoer voor leesbaarheid
:: ============================================================

cd /d "C:\Users\ms-iv\Downloads"

:: Datum ophalen in jjjj-mm-dd formaat
powershell -NoProfile -Command "[System.Threading.Thread]::CurrentThread.CurrentCulture = 'en-US'; Get-Date -Format 'yyyy-MM-dd'" > temp_datum.txt
set /p TODAY=<temp_datum.txt
del temp_datum.txt

:: Metadata invoer
set /p TITLE=Voer de titel van het boek in: 
set /p AUTHOR=Voer de auteur in: 
set /p PUBLISHER=Voer de uitgever (publisher) in: 
set /p BOOKDATEINPUT=Voer de publicatiedatum in (formaat: jjjj-mm-dd of leeg = vandaag): 

:: Invoer normaliseren via PowerShell (verwijdert CR/LF/spaties)
for /f %%x in ('powershell -NoProfile -Command "[Console]::Write((\"%BOOKDATEINPUT%\").Trim())"') do set BOOKDATEINPUT=%%x

:: Boekdatum instellen (fallback op TODAY)
if not "!BOOKDATEINPUT!"=="" (
    set "BOOKDATE=!BOOKDATEINPUT!"
) else (
    set "BOOKDATE=!TODAY!"
)

:: Metadata tonen vóór conversie
echo.
echo Titel: !TITLE!
echo Auteur: !AUTHOR!
echo Uitgever: !PUBLISHER!
echo Publicatiedatum: !BOOKDATE!
echo.

:: Converteren van elk .md bestand
for %%f in (*.md) do (
    echo Converting "%%f"...
    pandoc "%%f" -o "%%~nf.epub" ^
        --metadata=title:"!TITLE!" ^
        --metadata=author:"!AUTHOR!" ^
        --metadata=publisher:"!PUBLISHER!" ^
        --metadata=date:"!BOOKDATE!"
)

echo.
echo Alle bestanden zijn geconverteerd.
pause